@@ -151,6 +151,8 @@ class StudyDocuments:
         self.settings['query_organism'] = None
         self.settings['endpointfilter'] = None
         self.settings['query_guidance'] = None
+        self.settings['compositionfilter'] = " (component_s:CORE OR component_s:CONSTITUENT) "
+         
         self.settings['fields'] = "dbtag_hss,name_hs,publicname_hs,substanceType_hs,owner_name_hs,s_uuid_hs,substance_annotation_hss"
 
     def getSettings(self):
@@ -174,6 +176,11 @@ class StudyDocuments:
             endpointfilter = "AND {}".format(self.settings['endpointfilter'])
         else:
             endpointfilter=''
+            
+        if self.settings['compositionfilter'] != None:
+            compositionfilter = "AND {}".format(self.settings['compositionfilter'])
+        else:
+            compositionfilter=''            
 
         if _params:
             paramsFilter = ' OR filter(type_s:params {})'.format(studyfilter)
@@ -184,7 +191,7 @@ class StudyDocuments:
         else:
             conditionsFilter=''
         if _composition:
-            compositionFilter='OR filter(type_s:composition AND component_s:CORE)'
+            compositionFilter=' OR filter(type_s:composition {})'.format(compositionfilter)
         else:
             compositionFilter=''
 
@@ -236,8 +243,8 @@ class StudyDocuments:
 
             params = {}
             conditions = {}
-            cas = {}
-            einecs = {}
+            
+            components = []
 
             if (not '_childDocuments_' in doc):
                 continue
@@ -245,19 +252,34 @@ class StudyDocuments:
 
             for childdoc in doc['_childDocuments_']:
                 if (childdoc['type_s'] == 'composition'):
-                    if (childdoc['component_s'] == "CORE"):
-                        try:
-                            caskey=childdoc['CASRN_s']
-                            cas[caskey] =  childdoc['component_s']
-                        except:
-                            pass  # val does not exist at all
-                        try:
-                            ekey=childdoc['EINECS_s']
-                            einecs[ekey] =  childdoc['component_s']
-                        except:
-                            pass  # val does not exist at all
-
-
+                    component = {}
+                    prefix="c{}.".format(len(components)+1);
+                    component[prefix+"type"] = childdoc['component_s']
+                    try:
+                        component[prefix+"CAS"] = childdoc['CASRN_s']
+                    except:
+                        pass  # val does not exist at all
+                    try:
+                        component[prefix+"EINECS"] =childdoc['EINECS_s']
+                    except:
+                        pass  # val does not exist at all
+                    try:
+                        component[prefix+"SMILES"] =childdoc['SMILES_s']
+                    except:
+                        pass  # val does not exist at all
+                    try:
+                        component[prefix+"InChIKey"] =childdoc['InChIKey_s']
+                    except:
+                        pass  # val does not exist at all                        
+                    try:
+                        component[prefix+"InChI"] =childdoc['InChI_s']
+                    except:
+                        pass  # val does not exist at all       
+                    try:
+                        component[prefix+"formula"] =childdoc['formula_s']
+                    except:
+                        pass  # val does not exist at all                         
+                    components.append(component)    
 
                 if (childdoc['type_s'] == 'params'):
                     #display(childdoc)
@@ -533,12 +555,10 @@ class StudyDocuments:
                     except :
                         pass
 
-                    for key,value in cas.items():
-                        row['c.CAS']=key
-                    for key,value in einecs.items():
-                        row['c.EINECS']=key
-
-
+                    for component in components:
+                        row.update(component)
+                    
+                    
                     rows.append(row)
         return (rows)
 
